# Configure databricks cli


If you installed the requirements file already all you have to do is to have a file in `$HOME/.databrickscfg` like this:

```
[DEFAULT]
host = https://dbc-59447477-336d.cloud.databricks.com
token = xxxxyyyy
```

The token you have to get from an API key in your databricks account [here](https://dbc-59447477-336d.cloud.databricks.com/#setting/account).
